==> loadmychunks-1.2.0%2B1.20.1%2Bfabric-sources.jar: com/drathonix/loadmychunks/common/item/BlockItemHasTooltip.java <==
package com.drathonix.loadmychunks.common.item;

import com.drathonix.loadmychunks.common.util.Message;
import org.jetbrains.annotations.Nullable;

import java.util.List;
import net.minecraft.class_1747;
import net.minecraft.class_1799;
import net.minecraft.class_1836;
import net.minecraft.class_1937;
import net.minecraft.class_2248;
import net.minecraft.class_2561;
import net.minecraft.class_7923;

public class BlockItemHasTooltip extends class_1747 {
    private final int nLines;

    public BlockItemHasTooltip(class_2248 block, class_1793 properties, int nLines) {
        super(block, properties);
        this.nLines = nLines;
    }

    //? if <=1.20.5 {
    @Override
    public void method_7851(class_1799 itemStack, @Nullable class_1937 level, List<class_2561> list, class_1836 tooltipFlag) {
        super.method_7851(itemStack, level, list, tooltipFlag);
        for (int i = 0; i < nLines; i++) {
            list.add(Message.translatable(getTooltipTranslationKey(i)));
        }

    }
    //?} else {
    /*@Override
    public void appendHoverText(ItemStack itemStack, TooltipContext tooltipContext, List<Component> list, TooltipFlag tooltipFlag) {
        super.appendHoverText(itemStack, tooltipContext, list, tooltipFlag);
        for (int i = 0; i < nLines; i++) {
            list.add(Message.translatable(getTooltipTranslationKey(i)));
        }
    }
    *///?}

    public String getTooltipTranslationKey(int k){
        //? if <=1.19.3 {
        /*return "tooltip." + Registry.ITEM.getKey(this).toString().replace(":",".") + "." + k;
        *///?} else {
        return "tooltip." + class_7923.field_41178.method_10221(this).toString().replace(":",".") + "." + k;
        //?}
    }
}

==> loadmychunks-1.2.1%2B1.21.2%2Bfabric-sources.jar: com/drathonix/loadmychunks/common/item/BlockItemHasTooltip.java <==
package com.drathonix.loadmychunks.common.item;

import com.drathonix.loadmychunks.common.util.Message;
import org.jetbrains.annotations.Nullable;

import java.util.List;
import net.minecraft.class_1747;
import net.minecraft.class_1799;
import net.minecraft.class_1836;
import net.minecraft.class_2248;
import net.minecraft.class_2561;
import net.minecraft.class_7923;

public class BlockItemHasTooltip extends class_1747 {
    private final int nLines;

    public BlockItemHasTooltip(class_2248 block, class_1793 properties, int nLines) {
        super(block, properties);
        this.nLines = nLines;
    }

    //? if <=1.20.5 {
    /*@Override
    public void appendHoverText(ItemStack itemStack, @Nullable Level level, List<Component> list, TooltipFlag tooltipFlag) {
        super.appendHoverText(itemStack, level, list, tooltipFlag);
        for (int i = 0; i < nLines; i++) {
            list.add(Message.translatable(getTooltipTranslationKey(i)));
        }

    }
    *///?} else {
    @Override
    public void method_7851(class_1799 itemStack, class_9635 tooltipContext, List<class_2561> list, class_1836 tooltipFlag) {
        super.method_7851(itemStack, tooltipContext, list, tooltipFlag);
        for (int i = 0; i < nLines; i++) {
            list.add(Message.translatable(getTooltipTranslationKey(i)));
        }
    }
    //?}

    public String getTooltipTranslationKey(int k){
        //? if <=1.19.3 {
        /*return "tooltip." + Registry.ITEM.getKey(this).toString().replace(":",".") + "." + k;
        *///?} else {
        return "tooltip." + class_7923.field_41178.method_10221(this).toString().replace(":",".") + "." + k;
        //?}
    }
}
